//***************************************************************
//  DoodleCanvasIC.java       Authors: Lewis and Loftus
//                            Updated: Bary W Pollack
//
//  A DoodleCanvasIC is a drawing surface for creating doodles.
//  Demonstrates use of inner classes.
//***************************************************************

import java.awt.*;
import java.awt.event.*;

class DoodleCanvasIC extends Canvas {
    //------------------------------------------------------------
    //  Creates an initially empty canvas.
    //------------------------------------------------------------
    public DoodleCanvasIC() {
        addMouseListener(new MouseHandler());
        addMouseMotionListener(new MouseMotionHandler());

        setBackground(Color.white);
        setSize(CANVAS_WIDTH, CANVAS_HEIGHT);
    }

    class MouseHandler implements MouseListener {
        //------------------------------------------------------------
        //  Sets up the initial point for a new doodle line.
        //------------------------------------------------------------
        public void mousePressed(MouseEvent event) {
            Point first = event.getPoint();
            lastX = first.x;
            lastY = first.y;
        }
        
        public void mouseReleased(MouseEvent event) {}
        public void mouseClicked(MouseEvent event) {}
        public void mouseEntered(MouseEvent event) {}
        public void mouseExited(MouseEvent event) {}
    }

    class MouseMotionHandler implements MouseMotionListener {
        //------------------------------------------------------------
        //  Draws a line from the last point to the current point.
        //------------------------------------------------------------
        public void mouseDragged(MouseEvent event) {
            Point current = event.getPoint();
    
            Graphics page = getGraphics();
            page.drawLine(lastX, lastY, current.x, current.y);
    
            lastX = current.x;
            lastY = current.y;
        }

        public void mouseMoved(MouseEvent event) {}
    }

    //------------------------------------------------------------
    //  Clears the canvas.
    //------------------------------------------------------------
    public void clear() {
        Graphics page = getGraphics();
        page.drawRect(0, 0, CANVAS_WIDTH, CANVAS_HEIGHT);
        repaint();
    }

    private final int CANVAS_WIDTH  = 200;
    private final int CANVAS_HEIGHT = 200;
    private int lastX, lastY;
}
